# Discordub

The only package to manage your user!!

## How to install:

To install this package, run ```pip install discordub```

## Tutorial

Some things that this package includes is the add & subtract function. Here's an example of the add:

```
import discordub as dub

#coming soon
```

### For the full documentation, please visit https://qloha.github.io/dicordub